@@ -11,11 +11,8 @@ import Tools
 import Data.Char
 import Text.Printf
 import Babel
-import Control.Monad (guard)
 import Data.String.HT (trim)
 import Data.List.Split
-import Text.Highlighting.Kate
-import Text.Blaze.Html.Renderer.String
 import Data.Tuple
 import Data.Hashable
 import Hex
@@ -300,23 +297,12 @@ treeToHtml2 ll
                    return $ wikiLinkCaption l st
         nodeToHtml (Environment Tag (TagAttr "br" _) _) = return "<br/>"
         nodeToHtml (Environment Tag (TagAttr "script" _) _) = return []
-        nodeToHtml (Environment Source (TagAttr _ a) l)
+        nodeToHtml (Environment Source (TagAttr _ _) l)
           = do let g = case reverse l of
                            [] -> []
                            (x : xs) -> if x == (C '\n') then reverse xs else l
-               let f = shallowFlatten (map renormalize (breakLines3 linewidth l))
                d <- treeToHtml2 (breakLines3 linewidth g)
-               st <- get
-               return $
-                 case
-                   do aa <- Map.lookup "lang" a
-                      guard (not (getInFootnote st))
-                      guard (not ((getInTab st) > 0))
-                      return aa
-                   of
-                     Just j -> (renderHtml
-                                  ((formatHtmlBlock defaultFormatOpts) (highlightAs j f)))
-                     Nothing -> (rtrim d)
+               return $ (rtrim d)
         nodeToHtml (Environment Template (Str s) l) = templateToHtml l s
         nodeToHtml (Environment Wikitable _ l)
           = walk "<table><tr>" l "</table></tr>"
