@@ -26,15 +26,6 @@ data MyError = DownloadError String String
 
 
 
-deriving instance Generic Network.URL.URL
-deriving instance Generic Network.URL.Host
-deriving instance Generic Network.URL.Protocol
-deriving instance Generic Network.URL.URLType
-
-deriving instance Serialize Network.URL.URL
-deriving instance Serialize Network.URL.Host
-deriving instance Serialize Network.URL.Protocol
-deriving instance Serialize Network.URL.URLType
 
 
 {-DHUN| A monad for dealing with errors DHUN-}
@@ -76,7 +67,7 @@ instance Show MyError where
 
 data Contributor = Contributor{name :: String, edits :: Integer,
                                href :: String}
-                 deriving (Eq, Ord, Show, Read)
+                 deriving (Eq, Ord, Show, Read, Serialize, Generic)
 
 {-DHUN| The sum of two contribors is defined as the new contribor with the same name and homepage and the edits summed up. Of course this makes only sense when summing up edits for the same contributor, which is not checked but has to be ensured by hand DHUN-}
 
@@ -97,12 +88,12 @@ imperativeStateZero
   = do v <- newMVar (0 :: Int)
        return
          ImperativeState{audict = [], fullUrl = fullWikiUrlZero,
-                         tmpPath = "", counter = v, loadacu = Right []}
+                         tmpPath = "", counter = v, loadacu = Right [], vectorr=False, noparentis=False}
 
 data ImperativeState = ImperativeState{audict ::
                                        [(Map String Contributor)],
                                        fullUrl :: FullWikiUrl, tmpPath :: String,
-                                       counter :: MVar Int, loadacu :: Either [FilePath] [Anything Char]}
+                                       counter :: MVar Int, loadacu :: Either [FilePath] [Anything Char], vectorr::Bool, noparentis::Bool}
 
 
 
@@ -141,7 +132,7 @@ data FullConfig = FullConfig{headers :: Maybe String,
                              vector :: Bool, copy :: Maybe String, mainPath :: String,
                              server :: Maybe Int, outputType :: OutputType,
                              selfTest :: Maybe (Integer, Integer), compile :: Maybe String,
-                             imgctrb :: Maybe String, convert:: Maybe (ConvertState)}
+                             imgctrb :: Maybe String, convert:: Maybe (ConvertState), noparent::Bool}
                 deriving (Show, Read, Serialize, Generic)
 
 fullconfigbase :: FullConfig
@@ -150,4 +141,4 @@ fullconfigbase
                outputFilename = "", inputUrl = "", runMode = HTML No, paper = "A4",
                vector = False, copy = Nothing, mainPath = "", server = Nothing,
                outputType = PlainPDF, selfTest = Nothing, compile = Nothing,
-               imgctrb = Nothing, convert =Nothing}
+               imgctrb = Nothing, convert =Nothing, noparent=False}
