@@ -469,6 +469,8 @@ htmlchars
      ("#254", "{\\mbox{$\\text{\\thorn}$}}"),
      ("#255", "{\\mbox{$\\text{\\\"y}$}}"),
      ("yuml", "{\\mbox{$\\text{\\\"y}$}}"),
+     ("#10", "{\\newline}"),
+     ("#39", "'"),
      ("sum", "{\\mbox{$\\sum$}}"), ("ang", "{\\mbox{$\\angle$}}"),
      ("and", "{\\mbox{$\\wedge$}}"), ("cap", "{\\mbox{$\\cap$}}"),
      ("cup", "{\\mbox{$\\cup$}}"), ("int", "{\\mbox{$\\int$}}"),
