@@ -45,7 +45,7 @@ data MyState = MyState{getImages :: [String], getJ :: Int,
                        currentUrl :: String, fndict :: Map String [Anything Char],
                        tablist :: [[String]], tabmap :: Map Int (Map Int Double),
                        fontStack :: [FontStyle], font :: Font, langu :: Maybe String,
-                       forms :: Map String Int, lastChar :: Char, lastFontChanged :: Bool}
+                       forms :: Map String Int, lastChar :: Char, lastFontChanged :: Bool, getInCaption :: Bool, vector:: Bool}
              deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| Renderer is the State monad using MyState as mutable state DHUN-}
@@ -66,7 +66,7 @@ initialState
             fontStack =
               [FontStyle{stylebase = Normal, bold = False, italic = False}],
             font = ComputerModernRoman, langu = Nothing, forms = Map.empty,
-            lastChar = ' ', lastFontChanged = False}
+            lastChar = ' ', lastFontChanged = False, getInCaption=False, vector=False}
 
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is not a sister project of wikipedia, so not wikibooks wikisource, etc. DHUN-}
 
